summaryrefslogtreecommitdiff
path: root/src/game-server/state.hpp
diff options
context:
space:
mode:
authorBjørn Lindeijer <bjorn@lindeijer.nl>2009-04-23 21:00:16 +0200
committerBjørn Lindeijer <bjorn@lindeijer.nl>2009-04-26 17:18:21 +0200
commite726c34606f85347e70a0deb6b180db03b6d0c25 (patch)
treee78e5ba07dd9484abed035cc3e63744101bbef57 /src/game-server/state.hpp
parenta3f72002fa02cd4c525f101c5f240a22d4480119 (diff)
downloadmanaserv-e726c34606f85347e70a0deb6b180db03b6d0c25.tar.gz
manaserv-e726c34606f85347e70a0deb6b180db03b6d0c25.tar.bz2
manaserv-e726c34606f85347e70a0deb6b180db03b6d0c25.tar.xz
manaserv-e726c34606f85347e70a0deb6b180db03b6d0c25.zip
Merged MovingObject into the Being class
Also renamed Object to Actor, to make it sound a little less generic. Cleans up a bit the rather big hierarchy of different object types we have.
Diffstat (limited to 'src/game-server/state.hpp')
-rw-r--r--src/game-server/state.hpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/game-server/state.hpp b/src/game-server/state.hpp
index f5595bc8..e08073b7 100644
--- a/src/game-server/state.hpp
+++ b/src/game-server/state.hpp
@@ -26,7 +26,7 @@
class MapComposite;
class Thing;
-class Object;
+class Actor;
class Character;
namespace GameState
@@ -37,8 +37,8 @@ namespace GameState
void update(int worldTime);
/**
- * Inserts an object in the game world.
- * @return false if the insertion failed and the object is in limbo.
+ * Inserts an thing in the game world.
+ * @return false if the insertion failed and the thing is in limbo.
* @note No update may be in progress.
*/
bool insert(Thing *)
@@ -48,7 +48,7 @@ namespace GameState
;
/**
- * Inserts an object in the game world. Deletes the object if the insertion
+ * Inserts a thing in the game world. Deletes the thing if the insertion
* failed.
* @return false if the insertion failed.
* @note No update may be in progress. Invalid for characters.
@@ -56,9 +56,9 @@ namespace GameState
bool insertSafe(Thing *);
/**
- * Removes an object from the game world.
+ * Removes a thing from the game world.
* @note No update may be in progress.
- * @note The object is not destroyed by this call.
+ * @note The thing is not destroyed by this call.
*/
void remove(Thing *);
@@ -73,14 +73,14 @@ namespace GameState
* Enqueues an insert event.
* @note The event will be executed at end of update.
*/
- void enqueueInsert(Object *);
+ void enqueueInsert(Actor *);
/**
* Enqueues a remove event.
* @note The event will be executed at end of update.
- * @note The object will be destroyed at that time.
+ * @note The thing will be destroyed at that time.
*/
- void enqueueRemove(Object *);
+ void enqueueRemove(Actor *);
/**
* Enqueues a warp event.
@@ -89,15 +89,15 @@ namespace GameState
void enqueueWarp(Character *, MapComposite *, int x, int y);
/**
* Says something to an object
* @note passing NULL as source generates a message from "Server:"
*/
- void sayTo(Object *destination, Object *source, std::string const &text);
+ void sayTo(Actor *destination, Actor *source, std::string const &text);
/**
* Says something to everything around an object.
*/
- void sayAround(Object *, std::string const &text);
+ void sayAround(Actor *, std::string const &text);
/**
* Says something to every player on the server.
@@ -89,15 +89,15 @@ namespace GameState
void enqueueWarp(Character *, MapComposite *, int x, int y);
/**
- * Says something to an object
+ * Says something to an actor.
* @note passing NULL as source generates a message from "Server:"
*/
@@ -89,15 +89,15 @@ namespace GameState
/**
- * Says something to everything around an object.
+ * Says something to everything around an actor.
*/